"""
ENAHO Merger - Geographic Module
================================

Módulo para fusión con datos geográficos.
"""

from .merger import ENAHOGeographicMerger, GeographicMerger

__all__ = ["GeographicMerger", "ENAHOGeographicMerger"]
